unit sp_tools;
interface
  uses dos;

  var sysop_flag : byte;       { aus der Kommandozeile                }
      priv_level : byte;       { PRIV-Level der Gegenstation, aus der }
                               { Kommandozeile                        }
      your_call  : string[10]; { Call der anrufenden Station, aus der }
                               { Kommandozeile                        }
      my_call    : string[10]; { eigenes Call; wird aus CONFIG.SP     }
                               { ermittelt ber den TNC-Initparameter }
                               { INI=I <My_Call>                      }
      language   : byte;       { 0 : Deutsch, 1 : Englisch            }
                               { Der Wert wird aus CONFIG.SP ber     }
                               { den Eintrag CFG=LANG:0 oder 1        }
      data_file  : text;

  procedure open_info_file (pathname: string; filename : string);

  function get_user_parameter (ind : byte) : string;

  procedure show_bug (err_nr : integer);

implementation
  var   err : integer;
  const msg : array [0..1,1..6] of string =
                (('zu wenig Parameter!',
                  'Dieses Programm kann nur von SP aus gestartet werden!',
                  'Fehler: die Datei CONFIG.SP kann nicht gefunden werden',
                  'Fehler: die Datei ', ' kann nicht gefunden werden',
                  'Programm beendet!'),
                 ('to less parameter!',
                  'This program can only be started from SP!',
                  'Error: Can''t find CONFIG.SP',
                  'Error: Can''t find ', '',
                  'Program aborted!')
                 );

  procedure open_info_file (pathname : string; filename : string);
  begin
    {$I-}
    assign (data_file, pathname + '\'+ filename);
    reset (data_file);
    {$I+}
    if ioresult <> 0 then
    begin
      writeln (msg [language,4], filename, msg [language,5]);
      writeln (msg [language,6]);
      show_bug (2);
    end;
  end;

  function get_user_parameter (ind : byte) : string;
  begin
    if ind > paramcount - 3
    then begin
      writeln (msg [language,1]);
      writeln (msg [language,6]);
      show_bug (3);
      end
    else get_user_parameter := (paramstr (ind));
  end;

  procedure read_cfg_file;
    var cfg_dir  : string[80];
        line     : string [255];
        cfg_file : text;
        p        : integer;
  begin
    my_call := '';
    language := 1;
    cfg_dir := getenv ('SPDIR');
    if cfg_dir = '' then
      begin
        writeln (msg [language,3]);
        writeln (msg [language,6]);
        show_bug (4);
      end;
    {$I-}
    assign (cfg_file, cfg_dir+'\config.sp');
    reset (cfg_file);
    {$I+}
    if ioresult = 0
    then
    begin
      while not eof (cfg_file)
      do
      begin
        readln (cfg_file, line);
        p := pos ('CFG=LANG:', line);
        if p > 0
        then val (line [p+9], language, err);

        p := pos ('INI=I ', line);
        if p > 0
        then my_call := copy (line, 7, length (line) - 6);
      end;
    end
    else
      begin
        writeln (msg [language,3]);
        writeln (msg [language,6]);
        show_bug (4);
      end;
  end;

  procedure show_bug (err_nr : integer);
  const t1 : string = '                     """""     Hi, I''m a bug!';
        t2 : string = '                            My number is : ';
        t3 : string = '                      ( )      Please report this';
        t4 : string = '                       U       number to the author!';
  begin
    writeln;
    writeln (t1);
    writeln (t2, err_nr);
    writeln (t3);
    writeln (t4);
    writeln;
    halt (err_nr);
  end;

begin
  read_cfg_file;
  if paramcount < 3
  then begin
    writeln (msg [language,2]);
    writeln (msg [language,6]);
    show_bug (1);
  end;
  your_call := paramstr (paramcount);
  val (paramstr (paramcount - 1), priv_level, err);
  val (paramstr (paramcount - 2), sysop_flag, err);
end.
